"""Extended Textual Loading Indicator widget."""

from textual import widgets

from .._extensions import WidgetInitExtension


class LoadingIndicator(WidgetInitExtension, widgets.LoadingIndicator):
    """An extended display for an animated loading indicator."""



"""Extended Textual SelectionList widget."""

from typing import Any
from typing import Callable

from rich.text import TextType
from textual import events
from textual import widgets
from textual.widgets._selection_list import Selection
from textual.widgets._selection_list import SelectionType

from .._extensions import WidgetExtension


class SelectionList(WidgetExtension, widgets.SelectionList):  # pylint: disable=too-many-ancestors
    """An extended vertical selection list that allows making multiple selections."""

    def __init__(
        self,
        *selections: Selection | tuple[TextType, SelectionType] | tuple[TextType, SelectionType, bool],
        name: str | None = None,
        id: str | None = None,
        classes: str | None = None,
        disabled: bool = False,
        styles: dict[str, Any] | None = None,
        disabled_messages: list[type[events.Message]] | None = None,
        callbacks: dict[str, Callable] | None = None,
    ) -> None:
        """Initialize the selection list.

        Args:
            *selections: The content for the selection list.
            name: The name of the selection list.
            id: The ID of the selection list in the DOM.
            classes: The CSS classes of the selection list.
            disabled: Whether the selection list is disabled or not.
            styles: Local inline styles to apply on top of the class' styles for only this instance.
            disabled_messages: List of messages to disable on this widget instance only.
            callbacks: Mapping of callbacks to send messages to instead of sending to default handler.
        """
        super().__init__(
            *selections,
            name=name,
            id=id,
            classes=classes,
            disabled=disabled,
        )
        self.__extend_widget__(
            styles=styles,
            disabled_messages=disabled_messages,
            callbacks=callbacks,
        )



"""Collection of new, and extended, Textual widgets.

"Extended" Textual widgets strive to maintain 100% parity with their basic counterpart for all standard arguments,
such as id/children/etc. This is to ensure they can all be directly dropped into existing Textual applications, before
any extension functionality is used. All Textual basic widgets should be 100% forward compatible with Textology widgets,
and all Textology widgets should be 100% backwards compatible with Textual widgets, in settings where no extended
functionality is being used.
"""

from ._button import Button
from ._extensions import Clickable
from ._extensions import WidgetExtension
from ._extensions import WidgetInitExtension
from ._horizontal_menus import HorizontalMenus
from ._list_item import ListItem
from ._list_item_header import ListItemHeader
from ._list_item_meta import ListItemMeta
from ._list_view import ListView
from ._location import Location
from ._modal_dialog import ModalDialog
from ._store import Store
from ._textual._checkbox import Checkbox
from ._textual._containers import Center
from ._textual._containers import Container
from ._textual._containers import Grid
from ._textual._containers import Horizontal
from ._textual._containers import HorizontalScroll
from ._textual._containers import Middle
from ._textual._containers import PageContainer
from ._textual._containers import ScrollableContainer
from ._textual._containers import Vertical
from ._textual._containers import VerticalScroll
from ._textual._content_switcher import ContentSwitcher
from ._textual._data_table import DataTable
from ._textual._directory_tree import DirectoryTree
from ._textual._footer import Footer
from ._textual._header import Header
from ._textual._label import Label
from ._textual._loading_indicator import LoadingIndicator
from ._textual._log import Log
from ._textual._markdown import Markdown
from ._textual._markdown import MarkdownViewer
from ._textual._option_list import OptionList
from ._textual._pretty import Pretty
from ._textual._progress_bar import ProgressBar
from ._textual._radio_button import RadioButton
from ._textual._radio_set import RadioSet
from ._textual._rich_log import RichLog
from ._textual._select import Select
from ._textual._selection_list import SelectionList
from ._textual._sparkline import Sparkline
from ._textual._static import Static
from ._textual._switch import Switch
from ._textual._tabbed_content import TabbedContent
from ._textual._tabbed_content import TabPane
from ._textual._tabs import Tab
from ._textual._tabs import Tabs
from ._textual._text_input import TextInput
from ._textual._tooltip import Tooltip
from ._textual._tree import Tree
